@@ -18,8 +18,8 @@ from advpowcommon.ui.Notebook import NotebookMaemo5
 from advifswlib.interfaces.GSM import GSMInterface
 from advifswlib.interfaces.BT import BTInterface
 from advifswlib.interfaces.WLAN import WLANInterface
-from advifswlib.util.config import *
-from advifswlib.util.locale import *
+import advifswlib.util.config as config
+import advifswlib.util.locale as locale
 
 class AdvancedInterfaceSwitcherMaemo5(StatusMenuItem):
 
@@ -32,11 +32,11 @@ class AdvancedInterfaceSwitcherMaemo5(StatusMenuItem):
   def __init__(self):
 
     StatusMenuItem.__init__(self)
-    self.__lcl = get_locale()
+    self.__lcl = locale.get()
     self.__interfaces = []
     self.__animation_images = {}
     self.__gtk_swr = get_gtk_stock_wrapper()
-    self.__config = get_config()
+    self.__config = config.get()
     self.__config_ui = ConfigUIMaemo5()
     self.__sai_cacher = DITPixbufCacher(18)
     self.__sai_animator = DITPBCachedAnimator([], self.set_status_area_icon, cacher=self.__sai_cacher, time_out=1000)
@@ -48,20 +48,19 @@ class AdvancedInterfaceSwitcherMaemo5(StatusMenuItem):
     self.add(self.__smi_box)
     ilist = enumerate(ifaces)
 
-    #loaded_list = ''
-    #loaded_ifaces = 0
+    loaded_list = ''
+    loaded_ifaces = 0
     for iface in ilist:
       try:
         self.__interfaces.append(iface[1](self.__bus, self.process_sai, self.__show_settings_dialog))
         self.__smi_box.attach(self.__interfaces[iface[0]].get_button(), iface[0], iface[0]+1, 0, 1, gtk.EXPAND | gtk.FILL, gtk.SHRINK)
-        #loaded_ifaces += 1
-        #loaded_list = '%s\n%s' % (loaded_list, self.__interfaces[iface[0]].get_name())
+        loaded_ifaces += 1
+        loaded_list = '%s\n%s' % (loaded_list, self.__interfaces[iface[0]].get_name())
       except Exception, e:
-        #loaded_list = '%s\nError: %s' % (loaded_list, e)
-        print e
+        loaded_list = '%s\n%s\nError: %s\n' % (loaded_list, iface[1], e)
+        #print '%s: error: %s\n' % (iface[1],e)
         pass
-    #result = 'Loaded (%s/%s):%s\n' % (loaded_ifaces, len(ifaces), loaded_list)
-    #print result
+    print '\nLoaded (%s/%s)%s\n' % (loaded_ifaces, len(ifaces), loaded_list)
     self.show_all()
 
   def __show_settings_dialog(self, button=None):
