@@ -48,12 +48,19 @@ class AbstractInterface():
     self.state_control = None
     self.mode_control = None
 
+    self.set_config_option('mode-on-startup', self.get_modes())
+
     self.start_animation()
     self.__init_interfaces()
     self.__get_status()
     self.__init_signals()
     self.stop_animation()
-    self.__switch_state(int(self.get_config_value('startup-enable')))
+
+    start_state = int(self.get_config_value('enable-on-startup'))
+    self.__switch_state(start_state)
+    if start_state:
+      self.__switch_mode(self.get_modes().index(self.get_config_value('mode-on-startup')))
+
     #print self.__name, self.state['value'], self.state['mode'], self.state['strength']
     #self.__show_switch_dialog()
 
@@ -76,7 +83,10 @@ class AbstractInterface():
     return self.__bus
 
   def get_modes(self):
-    return self.state['modes']
+    return list(self.state['modes'])
+
+  def set_config_option(self, key, values):
+    self.__config.set_option('%s/%s' % (self.__config_path, key), values)
 
   def get_config_value(self, key):
     return self.__config.get_value('%s/%s' % (self.__config_path, key))
@@ -134,7 +144,7 @@ class AbstractInterface():
     if show_banner and self.state['banner'][windex]:
       text = '%s: %s' % (self.__name, self.__lcl.get_item(self.state['text'][windex]))
       if len(self.state['modes']) > 1:
-        text = '%s (%s)' % (text, self.__lcl.get_item(self.state['modes'][self.state['mode']]))
+        text = '%s (%s)' % (text, self.__lcl.get(self.state['modes'][self.state['mode']]))
       HildonBanner.show_information(self.__button, text)
 
   def __init_interfaces(self):
@@ -223,34 +233,36 @@ class AbstractInterface():
     return zip(texts, [self.__turn_state for t in texts])
 
   def __get_mode_controls(self):
-    texts = map(self.__lcl.get_item, list(self.state['modes']))
+    texts = map(self.__lcl.get, list(self.state['modes']))
     return zip(texts, [self.__turn_mode for t in texts])
 
   def __turn_state(self, widget=None, control=None, cstate=None):
     if widget.get_active():
       if not(cstate): cstate = control.get_active()
-      chstate = min(1, cstate)
-      state = self.state['value']
-      if cstate != state:
-        if chstate != state:
-          try:
-            self.__switch_state(cstate)
-          except:
-            self.switched()
-            self.__update_ui()
-        else:
-          control.set_active(state)
+      chstate = min(1, int(cstate))
+      if chstate != self.state['value']:
+        try:
+          self.__switch_state(chstate)
+        except:
+          self.switched()
+          self.__update_ui()
+      elif cstate != self.state['value']: control.set_active(self.state['value'])
 
   def __turn_mode(self, widget=None, control=None, cmode=None):
     if widget.get_active():
-      if cmode == None or cmode == (): cmode = control.get_active()
-      if cmode != self.state['mode']: self.turn_mode(cmode)
-
-  def turn_mode(self, mode):
-    pass
+      if not(cmode): cmode = control.get_active()
+      chmode = max(0, control.get_active())
+      if self.state['value'] and  chmode != self.state['mode']:
+        try:
+          self.__switch_mode(chmode)
+        except:
+          self.switched()
+          self.__update_ui()
+      elif cmode != self.state['mode']: control.set_active(self.state['mode'])
 
   def __switch_state(self, new_state):
     cstate = min(1, self.state['value'])
+    new_state = max(0, min(new_state, len(self.state['text']) - 1))
     if new_state != cstate:
       self.__button.set_value('...')
       try:
@@ -262,6 +274,19 @@ class AbstractInterface():
     else:
       self.__processing = False
 
+  def __switch_mode(self, new_mode):
+    cmode = max(0, self.state['mode'])
+    new_mode = max(0, min(new_mode, len(self.state['modes']) - 1))
+    if new_mode != cmode:
+      try:
+        self.turn_mode(new_mode)
+      except:
+        self.switched()
+        self.__update_ui()
+
+  def turn_mode(self, mode):
+    pass
+
   def start_animation(self):
     self.__smi_animator.start()
 
